# R CMD check will generate NOTE(s) with message 'no visible binding for
# global variable xyz'.  Adding this xyz variable to this file will remove
# this note.  See ?globalVariables for more information.

globalVariables(c(
  "DCUTDESC",
  "DCUTDT",
  "DCUTDTM",
  "DCUTDTC",
  "DCUT_TEMP_DCUTDT",
  "DCUT_TEMP_DCUTDTM",
  "DCUT_TEMP_DTHDT",
  "DCUT_TEMP_SDTM_DATE",
  "DTHDTC",
  "TEMP_DTC",
  "TEMP_FLAG",
  "dcut",
  ".",
  "USUBJID",
  "DCUT_TEMP_DATE",
  "source_data",
  "DCUT_TEMP_REMOVE",
  "DCUT_TEMP_DTHCHANGE",
  "TEMP_DCUT_KEEP"
))
